@@ -8,7 +8,7 @@ zypper --non-interactive addrepo -f -G https://download.opensuse.org/repositorie
 
 zypper --non-interactive refresh
 zypper --non-interactive up
-zypper --non-interactive in git-core jq curl ninja
+zypper --non-interactive in git-core jq yq curl ninja
 # From deploycala.py
 zypper --non-interactive in bison flex git make cmake gcc-c++
 zypper --non-interactive in yaml-cpp-devel libpwquality-devel parted-devel python3-devel
@@ -18,5 +18,5 @@ zypper --non-interactive in kf6-extra-cmake-modules
 zypper --non-interactive in "qt6-declarative-devel" "cmake(Qt6Concurrent)" "cmake(Qt6Gui)" "cmake(Qt6Network)" "cmake(Qt6Svg)" "cmake(Qt6Linguist)"
 zypper --non-interactive in "cmake(KF6CoreAddons)" "cmake(KF6DBusAddons)" "cmake(KF6Crash)"
 zypper --non-interactive in "cmake(KF6Parts)" # Also installs KF5 things
-zypper --non-interactive in "cmake(PolkitQt6-1)"
+zypper --non-interactive in "cmake(PolkitQt6-1)" appstream-qt6-devel
 true
