@@ -11,6 +11,7 @@
 #ifndef CALAMARES_PYTHONJOB_H
 #define CALAMARES_PYTHONJOB_H
 
+#include "DllMacro.h"
 #include "Job.h"
 #include "modulesystem/InstanceKey.h"
 
@@ -18,6 +19,11 @@
 
 #include <memory>
 
+#ifdef WITH_PYBIND11
+#error Source only for Boost::Python
+#else
+#endif
+
 namespace CalamaresPython
 {
 class PythonJobInterface;
@@ -27,7 +33,7 @@ class Helper;
 namespace Calamares
 {
 
-class PythonJob : public Job
+class DLLEXPORT PythonJob : public Job
 {
     Q_OBJECT
 public:
