@@ -13,12 +13,13 @@
 #include "GlobalStorage.h"
 #include "JobQueue.h"
 #include "PythonHelper.h"
+#include "locale/Global.h"
 #include "partition/Mount.h"
-#include "utils/CalamaresUtilsSystem.h"
 #include "utils/Logger.h"
 #include "utils/RAII.h"
 #include "utils/Runner.h"
 #include "utils/String.h"
+#include "utils/System.h"
 #include "utils/Yaml.h"
 
 #include <QCoreApplication>
@@ -28,7 +29,7 @@
 namespace bp = boost::python;
 
 static int
-handle_check_target_env_call_error( const CalamaresUtils::ProcessResult& ec, const QString& cmd )
+handle_check_target_env_call_error( const Calamares::ProcessResult& ec, const QString& cmd )
 {
     if ( !ec.first )
     {
@@ -60,12 +61,12 @@ bp_list_to_qstringlist( const bp::list& args )
     return list;
 }
 
-static inline CalamaresUtils::ProcessResult
+static inline Calamares::ProcessResult
 target_env_command( const QStringList& args, const std::string& input, int timeout )
 {
     // Since Python doesn't give us the type system for distinguishing
     // seconds from other integral types, massage to seconds here.
-    return CalamaresUtils::System::instance()->targetEnvCommand(
+    return Calamares::System::instance()->targetEnvCommand(
         args, QString(), QString::fromStdString( input ), std::chrono::seconds( timeout ) );
 }
 
@@ -78,10 +79,10 @@ mount( const std::string& device_path,
        const std::string& filesystem_name,
        const std::string& options )
 {
-    return CalamaresUtils::Partition::mount( QString::fromStdString( device_path ),
-                                             QString::fromStdString( mount_point ),
-                                             QString::fromStdString( filesystem_name ),
-                                             QString::fromStdString( options ) );
+    return Calamares::Partition::mount( QString::fromStdString( device_path ),
+                                        QString::fromStdString( mount_point ),
+                                        QString::fromStdString( filesystem_name ),
+                                        QString::fromStdString( options ) );
 }
 
 int
@@ -90,14 +91,12 @@ target_env_call( const std::string& command, const std::string& input, int timeo
     return target_env_command( QStringList { QString::fromStdString( command ) }, input, timeout ).first;
 }
 
-
 int
 target_env_call( const bp::list& args, const std::string& input, int timeout )
 {
     return target_env_command( bp_list_to_qstringlist( args ), input, timeout ).first;
 }
 
-
 int
 check_target_env_call( const std::string& command, const std::string& input, int timeout )
 {
@@ -105,7 +104,6 @@ check_target_env_call( const std::string& command, const std::string& input, int
     return handle_check_target_env_call_error( ec, QString::fromStdString( command ) );
 }
 
-
 int
 check_target_env_call( const bp::list& args, const std::string& input, int timeout )
 {
@@ -119,7 +117,6 @@ check_target_env_call( const bp::list& args, const std::string& input, int timeo
     return handle_check_target_env_call_error( ec, failedCmdList.join( ' ' ) );
 }
 
-
 std::string
 check_target_env_output( const std::string& command, const std::string& input, int timeout )
 {
@@ -128,7 +125,6 @@ check_target_env_output( const std::string& command, const std::string& input, i
     return ec.second.toStdString();
 }
 
-
 std::string
 check_target_env_output( const bp::list& args, const std::string& input, int timeout )
 {
@@ -168,7 +164,7 @@ load_yaml( const std::string& path )
 {
     const QString filePath = QString::fromStdString( path );
     bool ok = false;
-    auto map = CalamaresUtils::loadYaml( filePath, &ok );
+    auto map = Calamares::YAML::load( filePath, &ok );
     if ( !ok )
     {
         cWarning() << "Loading YAML from" << filePath << "failed.";
@@ -176,7 +172,6 @@ load_yaml( const std::string& path )
     return variantMapToPyDict( map );
 }
 
-
 PythonJobInterface::PythonJobInterface( Calamares::PythonJob* parent )
     : m_parent( parent )
 {
@@ -187,7 +182,6 @@ PythonJobInterface::PythonJobInterface( Calamares::PythonJob* parent )
     configuration = CalamaresPython::variantMapToPyDict( m_parent->m_configurationMap );
 }
 
-
 void
 PythonJobInterface::setprogress( qreal progress )
 {
@@ -258,11 +252,10 @@ host_env_process_output( const boost::python::list& args,
     return _process_output( Calamares::Utils::RunLocation::RunInHost, args, callback, input, timeout );
 }
 
-
 std::string
 obscure( const std::string& string )
 {
-    return CalamaresUtils::obscure( QString::fromStdString( string ) ).toStdString();
+    return Calamares::String::obscure( QString::fromStdString( string ) ).toStdString();
 }
 
 static QStringList
@@ -280,24 +273,19 @@ _gettext_languages()
     Calamares::GlobalStorage* gs
         = jq ? jq->globalStorage() : CalamaresPython::GlobalStoragePythonWrapper::globalStorageInstance();
 
-    QVariant localeConf_ = gs->value( "localeConf" );
-    if ( localeConf_.canConvert< QVariantMap >() )
+    QString lang = Calamares::Locale::readGS( *gs, QStringLiteral( "LANG" ) );
+    if ( !lang.isEmpty() )
     {
-        QVariant lang_ = localeConf_.value< QVariantMap >()[ "LANG" ];
-        if ( lang_.canConvert< QString >() )
+        languages.append( lang );
+        if ( lang.indexOf( '.' ) > 0 )
         {
-            QString lang = lang_.value< QString >();
+            lang.truncate( lang.indexOf( '.' ) );
+            languages.append( lang );
+        }
+        if ( lang.indexOf( '_' ) > 0 )
+        {
+            lang.truncate( lang.indexOf( '_' ) );
             languages.append( lang );
-            if ( lang.indexOf( '.' ) > 0 )
-            {
-                lang.truncate( lang.indexOf( '.' ) );
-                languages.append( lang );
-            }
-            if ( lang.indexOf( '_' ) > 0 )
-            {
-                lang.truncate( lang.indexOf( '_' ) );
-                languages.append( lang );
-            }
         }
     }
     return languages;
@@ -373,5 +361,4 @@ gettext_path()
     return bp::object();  // None
 }
 
-
 }  // namespace CalamaresPython
