@@ -12,6 +12,7 @@
 #include "GlobalStorage.h"
 #include "JobQueue.h"
 #include "Settings.h"
+#include "compat/Variant.h"
 #include "modulesystem/InstanceKey.h"
 #include "utils/Logger.h"
 
@@ -55,7 +56,7 @@ TestLibCalamares::testGSModify()
     gs.insert( key, value );
     QCOMPARE( gs.count(), 1 );
     QVERIFY( gs.contains( key ) );
-    QCOMPARE( gs.value( key ).type(), QVariant::Int );
+    QCOMPARE( Calamares::typeOf( gs.value( key ) ), Calamares::IntVariantType );
     QCOMPARE( gs.value( key ).toString(), QString( "17" ) );  // It isn't a string, but does convert
     QCOMPARE( gs.value( key ).toInt(), value );
 
@@ -137,8 +138,8 @@ TestLibCalamares::testGSLoadSave2()
     QVERIFY( gs1.loadYaml( filename ) );
     QCOMPARE( gs1.count(), 3 );  // From examining the file
     QVERIFY( gs1.contains( key ) );
-    cDebug() << gs1.value( key ).type() << gs1.value( key );
-    QCOMPARE( gs1.value( key ).type(), QVariant::List );
+    cDebug() << Calamares::typeOf( gs1.value( key ) ) << gs1.value( key );
+    QCOMPARE( Calamares::typeOf( gs1.value( key ) ), Calamares::ListVariantType );
 
     const QString yamlfilename( "gs.test.yaml" );
     QVERIFY( gs1.saveYaml( yamlfilename ) );
@@ -146,7 +147,7 @@ TestLibCalamares::testGSLoadSave2()
     Calamares::GlobalStorage gs2;
     QVERIFY( gs2.loadYaml( yamlfilename ) );
     QVERIFY( gs2.contains( key ) );
-    QCOMPARE( gs2.value( key ).type(), QVariant::List );
+    QCOMPARE( Calamares::typeOf( gs2.value( key ) ), Calamares::ListVariantType );
 }
 
 void
@@ -396,6 +397,7 @@ TestLibCalamares::testSettings()
         QVERIFY( s.brandingComponentName().isEmpty() );
         QVERIFY( !s.isValid() );
 
+        // *INDENT-OFF*
         s.setConfiguration( R"(---
 branding: default  # needed for it to be considered valid
 instances:
@@ -415,6 +417,7 @@ sequence:
         - welcome@hi
 )",
                             QStringLiteral( "<testdata>" ) );
+        // *INDENT-ON*
 
         QVERIFY( s.debugMode() );
         QCOMPARE( s.moduleInstances().count(), 4 );  // there are 4 module instances mentioned
