@@ -15,11 +15,12 @@
 #include "utils/String.h"
 
 #include <QFile>
+#include <QRegularExpression>
 #include <QString>
 
 static const char TZ_DATA_FILE[] = "/usr/share/zoneinfo/zone.tab";
 
-namespace CalamaresUtils
+namespace Calamares
 {
 namespace Locale
 {
@@ -60,7 +61,6 @@ getRightGeoLocation( QString str )
     return sign * num;
 }
 
-
 TimeZoneData::TimeZoneData( const QString& region,
                             const QString& zone,
                             const QString& country,
@@ -76,22 +76,21 @@ TimeZoneData::TimeZoneData( const QString& region,
 }
 
 QString
-TimeZoneData::tr() const
+TimeZoneData::translated() const
 {
     // NOTE: context name must match what's used in zone-extractor.py
     return QObject::tr( m_human, "tz_names" );
 }
 
-
 class RegionData : public TranslatableString
 {
 public:
     using TranslatableString::TranslatableString;
-    QString tr() const override;
+    QString translated() const override;
 };
 
 QString
-RegionData::tr() const
+RegionData::translated() const
 {
     // NOTE: context name must match what's used in zone-extractor.py
     return QObject::tr( m_human, "tz_regions" );
@@ -108,7 +107,7 @@ loadTZData( RegionVector& regions, ZoneVector& zones, QTextStream& in )
             continue;
         }
 
-        QStringList list = line.split( QRegExp( "[\t ]" ), SplitSkipEmptyParts );
+        QStringList list = line.split( QRegularExpression( "[\t ]" ), SplitSkipEmptyParts );
         if ( list.size() < 3 )
         {
             continue;
@@ -140,7 +139,7 @@ loadTZData( RegionVector& regions, ZoneVector& zones, QTextStream& in )
         }
 
         QString position = list.at( 1 );
-        int cooSplitPos = position.indexOf( QRegExp( "[-+]" ), 1 );
+        int cooSplitPos = position.indexOf( QRegularExpression( "[-+]" ), 1 );
         double latitude;
         double longitude;
         if ( cooSplitPos > 0 )
@@ -277,7 +276,7 @@ RegionsModel::data( const QModelIndex& index, int role ) const
     const auto& region = m_private->m_regions[ index.row() ];
     if ( role == NameRole )
     {
-        return region->tr();
+        return region->translated();
     }
     if ( role == KeyRole )
     {
@@ -293,13 +292,13 @@ RegionsModel::roleNames() const
 }
 
 QString
-RegionsModel::tr( const QString& region ) const
+RegionsModel::translated( const QString& region ) const
 {
     for ( const auto* p : m_private->m_regions )
     {
         if ( p->key() == region )
         {
-            return p->tr();
+            return p->translated();
         }
     }
     return region;
@@ -331,7 +330,7 @@ ZonesModel::data( const QModelIndex& index, int role ) const
     switch ( role )
     {
     case NameRole:
-        return zone->tr();
+        return zone->translated();
     case KeyRole:
         return zone->key();
     case RegionRole:
@@ -383,9 +382,8 @@ find( double startingDistance,
 const TimeZoneData*
 ZonesModel::find( const std::function< double( const TimeZoneData* ) >& distanceFunc ) const
 {
-    const auto* officialZone = CalamaresUtils::Locale::find( 1000000.0, m_private->m_zones, distanceFunc );
-    const auto* altZone
-        = CalamaresUtils::Locale::find( distanceFunc( officialZone ), m_private->m_altZones, distanceFunc );
+    const auto* officialZone = Calamares::Locale::find( 1000000.0, m_private->m_zones, distanceFunc );
+    const auto* altZone = Calamares::Locale::find( distanceFunc( officialZone ), m_private->m_altZones, distanceFunc );
 
     // If nothing was closer than the official zone already was, altZone is
     // nullptr; but if there is a spot-patch, then we need to re-find
@@ -443,7 +441,6 @@ ZonesModel::lookup( double latitude, double longitude ) const
     return const_cast< QObject* >( reinterpret_cast< const QObject* >( p ) );
 }
 
-
 ZonesModel::Iterator::operator bool() const
 {
     return 0 <= m_index && m_index < m_p->m_zones.count();
@@ -459,7 +456,7 @@ ZonesModel::Iterator::operator*() const
     return nullptr;
 }
 
-RegionalZonesModel::RegionalZonesModel( CalamaresUtils::Locale::ZonesModel* source, QObject* parent )
+RegionalZonesModel::RegionalZonesModel( Calamares::Locale::ZonesModel* source, QObject* parent )
     : QSortFilterProxyModel( parent )
     , m_private( privateInstance() )
 {
@@ -496,9 +493,8 @@ RegionalZonesModel::filterAcceptsRow( int sourceRow, const QModelIndex& ) const
     return ( zone->m_region == m_region );
 }
 
-
 }  // namespace Locale
-}  // namespace CalamaresUtils
+}  // namespace Calamares
 
 #include "utils/moc-warnings.h"
 
