@@ -10,7 +10,7 @@
 
 #include "TranslatableConfiguration.h"
 
-#include "LabelModel.h"
+#include "TranslationsModel.h"
 
 #include "utils/Logger.h"
 #include "utils/Variant.h"
@@ -19,7 +19,7 @@
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
 
-namespace CalamaresUtils
+namespace Calamares
 {
 namespace Locale
 {
@@ -38,7 +38,7 @@ TranslatedString::TranslatedString( const QVariantMap& map, const QString& key,
     : m_context( context )
 {
     // Get the un-decorated value for the key
-    QString value = CalamaresUtils::getString( map, key );
+    QString value = Calamares::getString( map, key );
     m_strings[ QString() ] = value;
 
     for ( auto it = map.constBegin(); it != map.constEnd(); ++it )
@@ -69,6 +69,7 @@ TranslatedString::get() const
 QString
 TranslatedString::get( const QLocale& locale ) const
 {
+    // TODO: keep track of special cases like sr@latin and ca@valencia
     QString localeName = locale.name();
     // Special case, sr@latin doesn't have the @latin reflected in the name
     if ( locale.language() == QLocale::Language::Serbian && locale.script() == QLocale::Script::LatinScript )
@@ -113,6 +114,5 @@ TranslatedString::get( const QLocale& locale ) const
     }
 }
 
-
 }  // namespace Locale
-}  // namespace CalamaresUtils
+}  // namespace Calamares
