@@ -30,7 +30,7 @@
 
 using std::cerr;
 
-namespace CalamaresUtils
+namespace Calamares
 {
 
 static QDir s_appDataDir( CMAKE_INSTALL_FULL_DATADIR );
@@ -69,7 +69,6 @@ isWritableDir( const QDir& dir )
     return true;
 }
 
-
 void
 setAppDataDir( const QDir& dir )
 {
@@ -147,14 +146,12 @@ isAppDataDirOverridden()
     return s_isAppDataDirOverridden;
 }
 
-
 QDir
 appDataDir()
 {
     return s_appDataDir;
 }
 
-
 QDir
 systemLibDir()
 {
@@ -162,7 +159,6 @@ systemLibDir()
     return path;
 }
 
-
 QDir
 appLogDir()
 {
@@ -184,4 +180,4 @@ appLogDir()
     return QDir::temp();
 }
 
-}  // namespace CalamaresUtils
+}  // namespace Calamares
