@@ -7,15 +7,15 @@
 
 #include "Permissions.h"
 
-#include "CalamaresUtilsSystem.h"
 #include "Logger.h"
+#include "System.h"
 
 #include <QString>
 #include <QStringList>
 
 #include <sys/stat.h>
 
-namespace CalamaresUtils
+namespace Calamares
 {
 
 Permissions::Permissions()
@@ -26,7 +26,6 @@ Permissions::Permissions()
 {
 }
 
-
 Permissions::Permissions( QString const& p )
     : Permissions()
 {
@@ -91,7 +90,7 @@ Permissions::apply( const QString& path, int mode )
 }
 
 bool
-Permissions::apply( const QString& path, const CalamaresUtils::Permissions& p )
+Permissions::apply( const QString& path, const Calamares::Permissions& p )
 {
     if ( !p.isValid() )
     {
@@ -105,8 +104,8 @@ Permissions::apply( const QString& path, const CalamaresUtils::Permissions& p )
         // uid_t and gid_t values to pass to that system call.
         //
         // Do a lame cop-out and let the chown(8) utility do the heavy lifting.
-        if ( CalamaresUtils::System::runCommand( { "chown", p.username() + ':' + p.group(), path },
-                                                 std::chrono::seconds( 3 ) )
+        if ( Calamares::System::runCommand( { "chown", p.username() + ':' + p.group(), path },
+                                            std::chrono::seconds( 3 ) )
                  .getExitCode() )
         {
             r = false;
@@ -121,5 +120,4 @@ Permissions::apply( const QString& path, const CalamaresUtils::Permissions& p )
     return r;
 }
 
-
-}  // namespace CalamaresUtils
+}  // namespace Calamares
