@@ -80,14 +80,19 @@ BrandingLoader::tryLoad( QTranslator* translator )
     {
         return false;
     }
+    // This is working backwards against m_prefix containing both
+    // a path and a branding-name. Split it in path + branding-name.
+    const int lastDirSeparator = m_prefix.lastIndexOf( QDir::separator() );
     QString brandingTranslationsDirPath( m_prefix );
-    brandingTranslationsDirPath.truncate( m_prefix.lastIndexOf( QDir::separator() ) );
-    QDir brandingTranslationsDir( brandingTranslationsDirPath );
-    if ( brandingTranslationsDir.exists() )
+    brandingTranslationsDirPath.truncate( lastDirSeparator );
+    QString filenameBase( m_prefix );
+    filenameBase.remove( 0, lastDirSeparator + 1 );
+
+    if ( QDir( brandingTranslationsDirPath ).exists() )
     {
-        QString filenameBase( m_prefix );
-        filenameBase.remove( 0, m_prefix.lastIndexOf( QDir::separator() ) + 1 );
-        if ( translator->load( m_localeName, filenameBase, "_", brandingTranslationsDir.absolutePath() ) )
+        const QString fileName = QStringLiteral( "%1_%2" ).arg( filenameBase, m_localeName );
+        cDebug() << Logger::SubEntry << "Loading" << fileName << "from" << brandingTranslationsDirPath;
+        if ( translator->load( fileName, brandingTranslationsDirPath ) )
         {
             cDebug() << Logger::SubEntry << "Branding using locale:" << m_localeName;
             return true;
@@ -113,7 +118,7 @@ tryLoad( QTranslator* translator, const QString& prefix, const QString& localeNa
     }
 
     // Or load from appDataDir -- often /usr/share/calamares -- subdirectory land/
-    QDir localeData( CalamaresUtils::appDataDir() );
+    QDir localeData( Calamares::appDataDir() );
     if ( localeData.exists()
          && translator->load( localeData.absolutePath() + QStringLiteral( "/lang/" ) + prefix + localeName ) )
     {
@@ -164,7 +169,7 @@ loadSingletonTranslator( TranslationLoader&& loader, QTranslator*& translator_p
 
 }  // namespace
 
-namespace CalamaresUtils
+namespace Calamares
 {
 static QTranslator* s_brandingTranslator = nullptr;
 static QTranslator* s_translator = nullptr;
@@ -172,7 +177,7 @@ static QTranslator* s_tztranslator = nullptr;
 static QString s_translatorLocaleName;
 
 void
-installTranslator( const CalamaresUtils::Locale::Translation::Id& locale, const QString& brandingTranslationsPrefix )
+installTranslator( const Calamares::Locale::Translation::Id& locale, const QString& brandingTranslationsPrefix )
 {
     s_translatorLocaleName = locale.name;
 
@@ -184,17 +189,17 @@ installTranslator( const CalamaresUtils::Locale::Translation::Id& locale, const
 void
 installTranslator()
 {
-    installTranslator( CalamaresUtils::Locale::Translation().id(), QString() );
+    installTranslator( Calamares::Locale::Translation().id(), QString() );
 }
 
-CalamaresUtils::Locale::Translation::Id
+Calamares::Locale::Translation::Id
 translatorLocaleName()
 {
     return { s_translatorLocaleName };
 }
 
 bool
-loadTranslator( const CalamaresUtils::Locale::Translation::Id& locale, const QString& prefix, QTranslator* translator )
+loadTranslator( const Calamares::Locale::Translation::Id& locale, const QString& prefix, QTranslator* translator )
 {
     return ::tryLoad( translator, prefix, locale.name );
 }
@@ -235,5 +240,4 @@ setAllowLocalTranslation( bool allow )
     s_allowLocalTranslations = allow;
 }
 
-
-}  // namespace CalamaresUtils
+}  // namespace Calamares
