@@ -13,7 +13,8 @@
 
 namespace Calamares
 {
-
+namespace Widgets
+{
 
 ClickableLabel::ClickableLabel( QWidget* parent )
     : QLabel( parent )
@@ -47,5 +48,5 @@ ClickableLabel::mouseReleaseEvent( QMouseEvent* event )
         emit clicked();
     }
 }
-
+}  // namespace Widgets
 }  // namespace Calamares
