@@ -376,14 +376,30 @@ class DMgdm(DisplayManager):
         GDM exists with different executable names, so search
         for one of them and use it.
         """
-        for executable, config in (
+        candidates = (
             ( "gdm", "etc/gdm/custom.conf" ),
-            ( "gdm3", "etc/gdm3/daemon.conf" )
-        ):
+            ( "gdm3", "etc/gdm3/daemon.conf" ),
+            ( "gdm3", "etc/gdm3/custom.conf" ),
+        )
+
+        def have_executable(executable : str):
             bin_path = "{!s}/usr/bin/{!s}".format(self.root_mount_point, executable)
             sbin_path = "{!s}/usr/sbin/{!s}".format(self.root_mount_point, executable)
-            if os.path.exists(bin_path) or os.path.exists(sbin_path):
-                # Keep the found-executable name around for later
+            return os.path.exists(bin_path) or os.path.exists(sbin_path)
+
+        def have_config(config : str):
+            config_path = "{!s}/{!s}".format(self.root_mount_point, config)
+            return os.path.exists(config_path)
+
+        # Look for an existing configuration file as a hint, then
+        # keep the found-executable name and config around for later.
+        for executable, config in candidates:
+            if have_config(config) and have_executable(executable):
+                self.executable = executable
+                self.config = config
+                return True
+        for executable, config in candidates:
+            if have_executable(executable):
                 self.executable = executable
                 self.config = config
                 return True
