@@ -14,6 +14,7 @@
 
 import os
 import re
+import copy
 
 import libcalamares
 
@@ -99,21 +100,11 @@ def disk_name_for_partition(partition):
 
 
 class FstabGenerator(object):
-    """ Class header
-
-    :param partitions:
-    :param root_mount_point:
-    :param mount_options:
-    :param ssd_extra_mount_options:
-    :param crypttab_options:
-    :param tmp_options:
-    """
-    def __init__(self, partitions, root_mount_point, mount_options,
-                 ssd_extra_mount_options, crypttab_options, tmp_options):
+    def __init__(self, partitions, root_mount_point, mount_options_list,
+                 crypttab_options, tmp_options):
         self.partitions = partitions
         self.root_mount_point = root_mount_point
-        self.mount_options = mount_options
-        self.ssd_extra_mount_options = ssd_extra_mount_options
+        self.mount_options_list = mount_options_list
         self.crypttab_options = crypttab_options
         self.tmp_options = tmp_options
         self.ssd_disks = set()
@@ -160,8 +151,12 @@ class FstabGenerator(object):
         if not mapper_name or not luks_uuid:
             return None
 
-        password = "/crypto_keyfile.bin"
         crypttab_options = self.crypttab_options
+        # Make sure to not use missing keyfile
+        if os.path.isfile(os.path.join(self.root_mount_point, "crypto_keyfile.bin")):
+            password = "/crypto_keyfile.bin"
+        else:
+            password = "none"
 
         # Set crypttab password for partition to none and remove crypttab options
         # if root partition was not encrypted
@@ -211,7 +206,7 @@ class FstabGenerator(object):
                     # so all subvolumes here should be safe to add to fstab
                     btrfs_subvolumes = libcalamares.globalstorage.value("btrfsSubvolumes")
                     for s in btrfs_subvolumes:
-                        mount_entry = partition
+                        mount_entry = copy.deepcopy(partition)
                         mount_entry["mountPoint"] = s["mountPoint"]
                         mount_entry["subvol"] = s["subvolume"]
                         dct = self.generate_fstab_line_info(mount_entry)
@@ -268,17 +263,7 @@ class FstabGenerator(object):
             libcalamares.utils.debug("Ignoring foreign swap {!s} {!s}".format(disk_name, partition.get("uuid", None)))
             return None
 
-        # If this is btrfs subvol a dedicated to a swapfile, use different options than a normal btrfs subvol
-        if filesystem == "btrfs" and partition.get("subvol", None) == "/@swap":
-            options = self.get_mount_options("btrfs_swap", mount_point)
-        else:
-            options = self.get_mount_options(filesystem, mount_point)
-
-        if is_ssd:
-            extra = self.ssd_extra_mount_options.get(filesystem)
-
-            if extra:
-                options += "," + extra
+        options = self.get_mount_options(mount_point)
 
         if mount_point == "/" and filesystem != "btrfs":
             check = 1
@@ -330,15 +315,18 @@ class FstabGenerator(object):
             if partition["mountPoint"]:
                 mkdir_p(self.root_mount_point + partition["mountPoint"])
 
-    def get_mount_options(self, filesystem, mount_point):
-        efiMountPoint = libcalamares.globalstorage.value("efiSystemPartition")
-        job_config = libcalamares.job.configuration
+    def get_mount_options(self, mountpoint):
+        """
+        Returns the mount options for a given mountpoint
 
-        if (mount_point == efiMountPoint and "efiMountOptions" in job_config):
-            return job_config["efiMountOptions"]
-
-        return self.mount_options.get(filesystem,
-                                      self.mount_options["default"])
+        :param mountpoint: A string containing the mountpoint for the fstab entry
+        :return: A string containing the mount options for the entry or "defaults" if nothing is found
+        """
+        mount_options_item = next((x for x in self.mount_options_list if x.get("mountpoint") == mountpoint), None)
+        if mount_options_item:
+            return mount_options_item.get("option_string", "defaults")
+        else:
+            return "defaults"
 
 
 def create_swapfile(root_mount_point, root_btrfs):
@@ -417,22 +405,21 @@ def run():
             swap_choice = None
 
     libcalamares.job.setprogress(0.1)
-    mount_options = conf.get("mountOptions", {})
-    ssd_extra_mount_options = conf.get("ssdExtraMountOptions", {})
+    mount_options_list = global_storage.value("mountOptionsList")
     crypttab_options = conf.get("crypttabOptions", "luks")
     tmp_options = conf.get("tmpOptions", {})
 
     # We rely on mount_options having a default; if there wasn't one,
     # bail out with a meaningful error.
-    if not mount_options:
+    if not mount_options_list:
+        libcalamares.utils.warning("No mount options defined, {!s} partitions".format(len(partitions)))
         return (_("Configuration Error"),
                 _("No <pre>{!s}</pre> configuration is given for <pre>{!s}</pre> to use.")
                 .format("mountOptions", "fstab"))
 
     generator = FstabGenerator(partitions,
                                root_mount_point,
-                               mount_options,
-                               ssd_extra_mount_options,
+                               mount_options_list,
                                crypttab_options,
                                tmp_options)
 
