@@ -502,14 +502,16 @@ QString
 Config::prettyStatus() const
 {
     QString status;
-    status += tr( "Keyboard model has been set to %1<br/>.", "@label, %1 is keyboard model, as in Apple Magic Keyboard" )
-                  .arg( m_keyboardModelsModel->label( m_keyboardModelsModel->currentIndex() ) );
+    status
+        += tr( "Keyboard model has been set to %1<br/>.", "@label, %1 is keyboard model, as in Apple Magic Keyboard" )
+               .arg( m_keyboardModelsModel->label( m_keyboardModelsModel->currentIndex() ) );
 
     QString layout = m_keyboardLayoutsModel->item( m_keyboardLayoutsModel->currentIndex() ).second.description;
     QString variant = m_keyboardVariantsModel->currentIndex() >= 0
         ? m_keyboardVariantsModel->label( m_keyboardVariantsModel->currentIndex() )
         : QString( "<default>" );
-    status += tr( "Keyboard layout has been set to %1/%2.", "@label, %1 is layout, %2 is layout variant" ).arg( layout, variant );
+    status += tr( "Keyboard layout has been set to %1/%2.", "@label, %1 is layout, %2 is layout variant" )
+                  .arg( layout, variant );
 
     return status;
 }
