@@ -37,7 +37,7 @@ parentCriticality( const QVariantMap& groupData, PackageTreeItem* parent )
 {
     if ( groupData.contains( "critical" ) )
     {
-        return CalamaresUtils::getBool( groupData, "critical", false );
+        return Calamares::getBool( groupData, "critical", false );
     }
     return parent ? parent->isCritical() : false;
 }
@@ -49,33 +49,36 @@ PackageTreeItem::PackageTreeItem( const QString& packageName, PackageTreeItem* p
     , m_isGroup( false )
     , m_isCritical( parent ? parent->isCritical() : false )
     , m_showReadOnly( parent ? parent->isImmutable() : false )
+    , m_showNoncheckable( false )
 {
 }
 
 PackageTreeItem::PackageTreeItem( const QVariantMap& groupData, PackageTag&& parent )
     : m_parentItem( parent.parent )
-    , m_packageName( CalamaresUtils::getString( groupData, "name" ) )
+    , m_packageName( Calamares::getString( groupData, "name" ) )
     , m_selected( parentCheckState( parent.parent ) )
-    , m_description( CalamaresUtils::getString( groupData, "description" ) )
+    , m_description( Calamares::getString( groupData, "description" ) )
     , m_isGroup( false )
     , m_isCritical( parent.parent ? parent.parent->isCritical() : false )
     , m_showReadOnly( parent.parent ? parent.parent->isImmutable() : false )
+    , m_showNoncheckable( false )
 {
 }
 
 PackageTreeItem::PackageTreeItem( const QVariantMap& groupData, GroupTag&& parent )
     : m_parentItem( parent.parent )
-    , m_name( CalamaresUtils::getString( groupData, "name" ) )
+    , m_name( Calamares::getString( groupData, "name" ) )
     , m_selected( parentCheckState( parent.parent ) )
-    , m_description( CalamaresUtils::getString( groupData, "description" ) )
-    , m_preScript( CalamaresUtils::getString( groupData, "pre-install" ) )
-    , m_postScript( CalamaresUtils::getString( groupData, "post-install" ) )
-    , m_source( CalamaresUtils::getString( groupData, "source" ) )
+    , m_description( Calamares::getString( groupData, "description" ) )
+    , m_preScript( Calamares::getString( groupData, "pre-install" ) )
+    , m_postScript( Calamares::getString( groupData, "post-install" ) )
+    , m_source( Calamares::getString( groupData, "source" ) )
     , m_isGroup( true )
     , m_isCritical( parentCriticality( groupData, parent.parent ) )
-    , m_isHidden( CalamaresUtils::getBool( groupData, "hidden", false ) )
-    , m_showReadOnly( CalamaresUtils::getBool( groupData, "immutable", false ) )
-    , m_startExpanded( CalamaresUtils::getBool( groupData, "expanded", false ) )
+    , m_isHidden( Calamares::getBool( groupData, "hidden", false ) )
+    , m_showReadOnly( Calamares::getBool( groupData, "immutable", false ) )
+    , m_showNoncheckable( Calamares::getBool( groupData, "noncheckable", false ) )
+    , m_startExpanded( Calamares::getBool( groupData, "expanded", false ) )
 {
 }
 
@@ -148,7 +151,6 @@ PackageTreeItem::parentItem() const
     return m_parentItem;
 }
 
-
 bool
 PackageTreeItem::hiddenSelected() const
 {
@@ -176,7 +178,6 @@ PackageTreeItem::hiddenSelected() const
     return m_selected != Qt::Unchecked;
 }
 
-
 void
 PackageTreeItem::setSelected( Qt::CheckState isSelected )
 {
@@ -236,17 +237,18 @@ PackageTreeItem::updateSelected()
     }
 }
 
-
 void
 PackageTreeItem::setChildrenSelected( Qt::CheckState isSelected )
 {
     if ( isSelected != Qt::PartiallyChecked )
+    {
         // Children are never root; don't need to use setSelected on them.
         for ( auto child : m_childItems )
         {
             child->m_selected = isSelected;
             child->setChildrenSelected( isSelected );
         }
+    }
 }
 
 void
