@@ -9,6 +9,7 @@
 
 #include "Config.h"
 
+#include "ActiveDirectoryJob.h"
 #include "CreateUserJob.h"
 #include "MiscJobs.h"
 #include "SetHostNameJob.h"
@@ -444,8 +445,6 @@ makeHostnameSuggestion( const QString& templateString, const QStringList& fullNa
 
     QString hostnameSuggestion = d.expand( templateString );
 
-    // RegExp for valid hostnames; if the suggestion produces a valid name, return it
-    static const QRegularExpression HOSTNAME_RX( "^[a-zA-Z0-9][-a-zA-Z0-9_]*$" );
     return hostnameSuggestion.indexOf( HOSTNAME_RX ) != -1 ? hostnameSuggestion : QString();
 }
 
@@ -656,6 +655,48 @@ Config::setRootPasswordSecondary( const QString& s )
     }
 }
 
+void
+Config::setActiveDirectoryUsed( bool used )
+{
+    m_activeDirectoryUsed = used;
+}
+
+bool
+Config::getActiveDirectoryEnabled() const
+{
+    return m_activeDirectory;
+}
+
+bool
+Config::getActiveDirectoryUsed() const
+{
+    return m_activeDirectoryUsed && m_activeDirectory;
+}
+
+void
+Config::setActiveDirectoryAdminUsername( const QString& s )
+{
+    m_activeDirectoryAdminUsername = s;
+}
+
+void
+Config::setActiveDirectoryAdminPassword( const QString& s )
+{
+    m_activeDirectoryAdminPassword = s;
+}
+
+void
+Config::setActiveDirectoryDomain( const QString& s )
+{
+    m_activeDirectoryDomain = s;
+}
+
+void
+Config::setActiveDirectoryIP( const QString& s )
+{
+    m_activeDirectoryIP = s;
+}
+
 QString
 Config::rootPassword() const
 {
@@ -913,6 +954,9 @@ Config::setConfigurationMap( const QVariantMap& configurationMap )
     m_sudoStyle = Calamares::getBool( configurationMap, "sudoersConfigureWithGroup", false ) ? SudoStyle::UserAndGroup
                                                                                              : SudoStyle::UserOnly;
 
+    // Handle Active Directory enablement
+    m_activeDirectory = Calamares::getBool( configurationMap, "allowActiveDirectory", false );
+
     // Handle *hostname* key and subkeys and legacy settings
     {
         bool ok = false;  // Ignored
@@ -990,6 +1034,15 @@ Config::createJobs() const
         jobs.append( Calamares::job_ptr( j ) );
     }
 
+    if ( getActiveDirectoryUsed() )
+    {
+        j = new ActiveDirectoryJob( m_activeDirectoryAdminUsername,
+                                    m_activeDirectoryAdminPassword,
+                                    m_activeDirectoryDomain,
+                                    m_activeDirectoryIP );
+        jobs.append( Calamares::job_ptr( j ) );
+    }
+
     j = new SetupGroupsJob( this );
     jobs.append( Calamares::job_ptr( j ) );
 
